So, welcome to my first ever **Python Project**! That is a game based on *Odd Even*, but with a twist of **Cricket!**
To install the Game, run `pip install OddEven-SP` in your Terminal. If you have already installed the game, then please run `pip install OddEven-SP --upgrade`.
Then to initiate the game, you need to create a new Python File and type:
```py
from OddEvenSP import odd_even_game
odd_even_game()
```
Enjoy! Make sure to give FeedBack!

[![PyPI Downloads](https://static.pepy.tech/badge/oddeven-sp)](https://pepy.tech/projects/oddeven-sp)
